@@ -16,7 +16,7 @@ use Text::Minify::XS v0.3.1 ();
 
 # RECOMMEND PREREQ:  Ref::Util::XS
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 sub call {
     my ($self, $env) = @_;
@@ -67,7 +67,7 @@ sub call {
 
 
             if (Plack::Util::header_exists( $res->[1], 'content-length' )) {
-                Plack::Util::header_set( $res->[1], 'content-length', length($res->[2]) );
+                Plack::Util::header_set( $res->[1], 'content-length', length( $res->[2][0] ) );
             }
 
             return;
@@ -91,7 +91,7 @@ Plack::Middleware::Text::Minify - minify text responses on the fly
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
